@@ -3,37 +3,36 @@
 #'
 #' Fits a density surface model (DSM) to detection adjusted counts from a spatially-referenced distance sampling analysis. \code{\link{dsm}} takes observations of animals, allocates them to segments of line (or strip transects) and optionally adjusts the counts based on detectability using a supplied detection function model. A generalized additive model, generalized mixed model or generalized linear model is then used to model these adjusted counts based on a formula involving environmental covariates.
 #'
-#' The response (LHS of `formula`) can be one of the following:
+#' The response (LHS of `formula`) can be one of the following (with restrictions outlined below):
 #' \tabular{ll}{
-#'   \code{n}, \code{count}, \code{N} \tab count in each segment\cr
-#'   \code{Nhat}, \code{abundance.est} \tab estimated abundance per segment, estimation is via a Horvitz-Thompson estimator. This should be used when there are covariates in the detection function.\cr
-#'   \code{presence} \tab interpret the data as presence/absence (remember to change the \code{family} argument to \code{binomial()}), detectability is not accounted for\cr
-#'   \code{D}, \code{density}, \code{Dhat}, \code{density.est} \tab density per segment\cr
+#'   \code{count} \tab count in each segment\cr
+#'   \code{abundance.est} \tab estimated abundance per segment, estimation is via a Horvitz-Thompson estimator.\cr
+#'   \code{density.est} \tab density per segment\cr
 #'  }
 #'
 #' The offset used in the model is dependent on the response:
 #' \tabular{ll}{
 #'   count \tab area of segment multiplied by average probability of detection in the segment\cr
 #'   estimated count \tab area of the segment\cr
-#'   presence \tab zero\cr
 #'   density \tab zero\cr
 #'  }
 #'
-#' In the latter two cases (density and presence estimation) observations can be weighted by segment areas via the \code{weights=} argument. By default (\code{weights=NULL}), when density or presence are estimated the weights are set to the segment areas (using \code{segment.area} or by calculating \code{2*}(strip width)\code{*Effort}) Alternatively \code{weights=1} will set the weights to all be equal.  A third alternative is to pass in a vector of length equal to the number of segments, containing appropriate weights.
+#' The \code{count} response can only be used when detection function covariates only vary between segments/points (not within). For example, weather conditions (like visibility or sea state) or foliage cover are usually acceptable as they do not change within the segment, but animal sex or behaviour will not work. The \code{abundance.est} response can be used with any covariates in the detection function.
+#'
+#' In the density case, observations can be weighted by segment areas via the \code{weights=} argument. By default (\code{weights=NULL}), when density is estimated the weights are set to the segment areas (using \code{segment.area} or by calculated from detection function object metadata and \code{Effort} data). Alternatively \code{weights=1} will set the weights to all be equal. A third alternative is to pass in a vector of length equal to the number of segments, containing appropriate weights.
 #'
 #' A example analyses are available at \url{http://examples.distancesampling.org}.
 #'
 #' @section Units:
 #'
-#' It is often the case that distances are collected in metres and segment lengths are recorded in kilometres. \code{dsm} allows you to provide a conversation factor (\code{convert.units}) to multiply the areas by. For example: if distances are in metres and segment lengths are in kilometres setting \code{convert.units=1000} will lead to the analysis being in metres. Setting \code{convert.units=1/1000} will lead to the analysis being in kilometres. The conversion factor will be applied to `segment.area` if that is specified.
+#' It is often the case that distances are collected in metres and segment lengths are recorded in kilometres. \code{dsm} allows you to provide a conversion factor (\code{convert.units}) to multiply the areas by. For example: if distances are in metres and segment lengths are in kilometres setting \code{convert.units=1000} will lead to the analysis being in metres. Setting \code{convert.units=1/1000} will lead to the analysis being in kilometres. The conversion factor will be applied to `segment.area` if that is specified.
 #'
 #' @section Large models:
 #'
 #' For large models, \code{engine="bam"} with \code{method="fREML"} may be useful. Models specified for \code{bam} should be as \code{gam}. READ \code{\link{bam}} before using this option; this option is considered EXPERIMENTAL at the moment. In particular note that the default basis choice (thin plate regression splines) will be slow and that in general fitting is less stable than when using \code{gam}. For negative binomial response, theta must be specified when using \code{bam}.
 #'
-#'
 #' @param formula formula for the surface. This should be a valid \code{\link{glm}}/\code{\link{gam}}/\code{\link{gamm}} formula. See "Details", below, for how to define the response.
-#' @param ddf.obj result from call to \code{\link{ddf}} or \code{\link[Distance]{ds}}. If \code{ddf.obj} is \code{NULL} then strip transects are assumed.
+#' @param ddf.obj result from call to \code{\link{ddf}} or \code{\link[Distance]{ds}}. If multiple detection functions are required a \code{list} can be provided. For strip/circle transects where it is assumed all objects are observed, see \code{\link{dummy_ddf}}. Mark-recapture distance sampling (\code{mrds}) models of type \code{io} (independent observers) are allowed.
 #' @param segment.data segment data, see \code{\link{dsm-data}}.
 #' @param observation.data observation data, see \code{\link{dsm-data}}.
 #' @param engine which fitting engine should be used for the DSM (\code{\link{glm}}/\code{\link{gam}}/\code{\link{gamm}}/\code{\link{bam}}).
@@ -41,11 +40,9 @@
 #' @param family response distribution (popular choices include \code{\link{quasipoisson}}, \code{\link{Tweedie}}/\code{\link{tw}} and \code{\link{negbin}}/\code{\link{nb}}). Defaults to \code{quasipossion}.
 #' @param group if \code{TRUE} the abundance of groups will be calculated rather than the abundance of individuals. Setting this option to \code{TRUE} is equivalent to setting the size of each group to be 1.
 #' @param control the usual \code{control} argument for a \code{gam}; \code{keepData} must be \code{TRUE} for variance estimation to work (though this option cannot be set for GLMs or GAMMs.
-#' @param availability an availability bias used to scale the counts/estimated  counts by. If we have \code{N} animals in a segment, then \code{N/availability} will be entered into the model. Uncertainty in the availability is not handled at present.
-#' @param strip.width if \code{ddf.obj}, above, is \code{NULL}, then this is where the strip width is specified (i.e. for a strip transect survey). This is sometimes (and more correctly) referred to as the half-width, i.e. right truncation minus left truncation.
-#' @param segment.area if `NULL` (default) segment areas will be calculated by multiplying the `Effort` column in `segment.data` by the (right minus left) truncation distance for the `ddf.obj` or by `strip.width`. Alternatively a vector of segment areas can be provided (which must be the same length as the number of rows in `segment.data`) or a character string giving the name of a column in `segment.data` which contains the areas. If \code{segment.area} is specified it takes precedent.
+#' @param availability an estimate of availability bias. For count models used to multiply the effective strip width (must be a vector of length 1 or length the number of rows in \code{segment.data}); for estimated abundance/estimated density models used to scale the response (must be a vector of length 1 or length the number of rows in \code{observation.data}). Uncertainty in the availability is not handled at present.
+#' @param segment.area if `NULL` (default) segment areas will be calculated by multiplying the `Effort` column in `segment.data` by the (right minus left) truncation distance for the `ddf.obj` or by `strip.width`. Alternatively a vector of segment areas can be provided (which must be the same length as the number of rows in `segment.data`) or a character string giving the name of a column in `segment.data` which contains the areas. If \code{segment.area} is specified it takes precident.
 #' @param weights weights for each observation used in model fitting. The default, \code{weights=NULL}, weights each observation by its area (see Details). Setting a scalar value (e.g. \code{weights=1}) all observations are equally weighted.
-#' @param transect type of transect (\code{"line"}, the default or \code{"point"}). This is overridden by the detection function transect type, this is usually only necessary when no detection function is specified.
 #' @param method The smoothing parameter estimation method. Default is \code{"REML"}, using Restricted Maximum Likelihood. See \code{\link{gam}} for other options. Ignored for \code{engine="glm"}.
 #' @param \dots anything else to be passed straight to \code{\link{glm}}/\code{\link{gam}}/\code{\link{gamm}}/\code{\link{bam}}.
 #' @return a \code{\link{glm}}/\code{\link{gam}}/\code{\link{gamm}} object, with an additional element, \code{ddf} which holds the detection function object.
@@ -89,79 +86,66 @@
 dsm <- function(formula, ddf.obj, segment.data, observation.data,
                 engine="gam", convert.units=1,
                 family=quasipoisson(link="log"), group=FALSE,
-                control=list(keepData=TRUE), availability=1, strip.width=NULL,
-                segment.area=NULL, weights=NULL, transect="line", method="REML",
+                control=list(keepData=TRUE), availability=1,
+                segment.area=NULL, weights=NULL, method="REML",
                 ...){
 
   stopifnot(engine %in% c("gam","bam","glm","gamm"))
 
   # if we have a model fitted using Distance, then just pull out the
   # ddf component
-  if(!is.null(ddf.obj)){
+  if(is.null(ddf.obj)){
+    stop("NULL detection functions no longer supported, see ?dummy_ddf")
+  }
+  # if we don't have one detection function, but the model was
+  # fitted using Distance, then just pull out the ddf component
+  if(all(class(ddf.obj)!="list")){
     if(all(class(ddf.obj)=="dsmodel")){
       ddf.obj <- ddf.obj$ddf
     }
-    # check that we are doing points with points or lines with lines and not
-    # something weird
-    if(( ddf.obj$meta.data$point & transect!="point") ||
-       (!ddf.obj$meta.data$point & transect!="line")){
-      stop(paste0("Detection function and density surface model have mismatched transect types!",
-                  "\n  Detection function is ",
-                    c("line", "point")[ddf.obj$meta.data$point+1], " transect",
-                  "\n  Density surface model is ", transect, " transect\n"))
+  }else{
+    if(length(ddf.obj) == 1){
+      ddf.obj <- ddf.obj[[1]]
+    }
+    for(i in seq_along(ddf.obj)){
+      if(all(class(ddf.obj[[i]])=="dsmodel")){
+        ddf.obj[[i]] <- ddf.obj[[i]]$ddf
+      }
     }
   }
 
 
   ## check the formula
   response <- as.character(formula)[2]
-  possible.responses <- c("D", "density", "Dhat", "density.est",
-                          "N", "count", "n",
-                          "Nhat", "abundance.est",
-                          "presence")
+  # throw an error if we have one of the deprecated responses
+  if(response %in% c("presence", "D", "density", "Dhat", "N", "Nhat", "n")){
+    stop(paste("Response", response, "is deprecated, see ?dsm for details."))
+  }
+  possible.responses <- c("density.est",
+                          "count",
+                          "abundance.est")
   if(!(response %in% possible.responses)){
     stop(paste("Model must be one of:",
-               paste(possible.responses,collapse=", ")))
+               paste(possible.responses, collapse=", ")))
   }
 
   ## check that the necessary columns exist in the data
   # NB this doesn't return anything just throws an error if something
   #    bad happens
-  check.cols(ddf.obj, segment.data, observation.data, strip.width, segment.area)
-
-  # what is the transect type?
-  if(!is.null(ddf.obj)){
-    if(ddf.obj$meta.data$point){
-      transect <- "point"
-    }else{
-      transect <- "line"
-    }
-  }
-
-  # if we're doing presence ignore detection function
-  if(response == "presence"){
-    if(!is.null(ddf.obj)){
-      ddf.obj <- NULL
-      warning("Detection function supplied for presence/absence model but will be ignored")
-    }
-    if(is.null(strip.width)){
-      stop("strip.width must be supplied for presence/absence models")
-    }
-  }
+  check.cols(ddf.obj, segment.data, observation.data, segment.area)
 
 
   ## build the data
   dat <- make.data(response, ddf.obj, segment.data, observation.data,
-                   group, convert.units, availability, strip.width,
-                   segment.area, family, transect)
+                   group, convert.units, availability, segment.area, family)
 
-  ## if we are not modelling density/presence, then add in the offset
+  ## if we are not modelling density, then add in the offset
   ##  to the formula
-  if(!(response %in% c("D","density","Dhat","density.est","presence"))){
-    formula <- as.formula(paste(c(as.character(formula)[c(2,1,3)],
+  if(!(response %in% c("density.est"))){
+    formula <- as.formula(paste(c(as.character(formula)[c(2, 1, 3)],
                                 "+ offset(off.set)"), collapse=""))
   }else{
-    # set the weights if we are doing density or presence estimation
+    # set the weights if we are doing density estimation
     if(is.null(weights)){
       weights <- dat$segment.area
     }else if(length(weights)==1){
