@@ -41,7 +41,7 @@ summary.dsm.var <- function(object, alpha=0.05, boxplot.coef=1.5,
     bootstrap.abund <- object$study.area.total
 
     # when we don't need to do the delta method
-    if(is.null(object$dsm.object$ddf) | object$ds.uncertainty){
+    if(any(class(object$dsm.object$ddf)=="fake_ddf") | object$ds.uncertainty){
 
       # if we used detection function uncertainty
       # or there was no detection function
@@ -147,18 +147,19 @@ summary.dsm.var <- function(object, alpha=0.05, boxplot.coef=1.5,
       sinfo$se <- sqrt(object$pred.var)
     }else{
       # re run the variance calculation, putting everything together
-      pd<-c()
-      off<-c()
+      pd <- c()
+      off <- c()
       for(i in 1:length(object$pred.data)){
-        pd<-rbind(pd,object$pred.data[[i]])
-        off<-rbind(off,object$off.set[[i]])
+        pd <- rbind(pd, object$pred.data[[i]])
+        off <- rbind(off, object$off.set[[i]])
       }
       object$pred.data <- pd
       object$off.set <- as.vector(off)
 
       if(object$var.prop){
-        var.prop <- dsm.var.prop(object$dsm.obj, object$pred.data,object$off.set,
-                                 object$seglen.varname, object$type.pred)
+        var.prop <- dsm.var.prop(object$dsm.obj, object$pred.data,
+                                 object$off.set, object$seglen.varname,
+                                 object$type.pred)
       }else{
         var.prop <- dsm.var.gam(object$dsm.obj, object$pred.data,object$off.set,
                                  object$seglen.varname, object$type.pred)
@@ -167,14 +168,6 @@ summary.dsm.var <- function(object, alpha=0.05, boxplot.coef=1.5,
       sinfo$se <- sqrt(var.prop$pred.var)
     }
     # grab the predicted values
-#    if(length(object$pred)==0){
-#      dsm.obj <- object$dsm.obj
-#      class(dsm.obj) <- c("dsm",class(dsm.obj))
-#      mod1.pred <- predict(dsm.obj,
-#                           newdata=object$pred.data,
-#                           off.set=object$off.set)
-#      sinfo$pred.est <- sum(mod1.pred,na.rm=TRUE)
-#    }else if(length(object$pred)>1 | length(object$pred)==0){
     if(length(object$pred)>1){
       sinfo$pred.est <- sum(unlist(object$pred), na.rm=TRUE)
     }else{
@@ -183,7 +176,7 @@ summary.dsm.var <- function(object, alpha=0.05, boxplot.coef=1.5,
 
     # if we're using variance propagation or there is no detection
     # function, then the CV is fine
-    if(sinfo$varprop | is.null(object$dsm.object$ddf)){
+    if(sinfo$varprop | any(class(object$dsm.object$ddf)=="fake_ddf")){
       # calculate the CV
       sinfo$cv <- sinfo$se/sinfo$pred.est
     }else{
@@ -191,9 +184,30 @@ summary.dsm.var <- function(object, alpha=0.05, boxplot.coef=1.5,
     # the delta method
       ddf.summary <- summary(object$dsm.object$ddf)
 
-      cvp.sq <- (ddf.summary$average.p.se/
-                 ddf.summary$average.p)^2
-      sinfo$detfct.cv <- sqrt(cvp.sq)
+      # setup everything to be multi-ddf compatible
+      if(!any(class(object$dsm.object$ddf)=="list")){
+        ddf <- list(object$dsm.object$ddf)
+      }else{
+        ddf <- object$dsm.object$ddf
+      }
+
+      sinfo$detfct.cv <- c()
+      cvp.sq <- 0
+      for(i in seq_along(ddf)){
+
+        this_ddf <- ddf[[i]]
+        if(all(class(this_ddf)!="fake_ddf")){
+          ddf.summary <- summary(this_ddf)
+
+          this_cvp.sq <- (ddf.summary$average.p.se/
+                          ddf.summary$average.p)^2
+          cvp.sq <- cvp.sq + this_cvp.sq
+        }else{
+          this_cvp.sq <- NA
+        }
+        sinfo$detfct.cv <- c(sinfo$detfct.cv, sqrt(this_cvp.sq))
+      }
+
       sinfo$gam.cv <- sinfo$se/sinfo$pred.est
 
       sinfo$cv <- sqrt(cvp.sq+sinfo$gam.cv^2)
